.. _anomaly_scores:

Anomaly scores
==============

Savings
-------

.. currentmodule:: skchange.anomaly_scores

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    BaseSaving
    Saving
    L2Saving

Local anomaly scores
--------------------

.. autosummary::
    :toctree: auto_generated/
    :template: class.rst

    BaseLocalAnomalyScore
    LocalAnomalyScore

Utility functions
-----------------

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    to_saving
    to_local_anomaly_score
